@@ -1,6 +1,6 @@
 
--- libquvi-scripts v0.4.0
--- Copyright (C) 2010  Toni Gundogdu <legatvs@gmail.com>
+-- libquvi-scripts v0.4.4
+-- Copyright (C) 2010-2012  Toni Gundogdu <legatvs@gmail.com>
 --
 -- This file is part of libquvi-scripts <http://quvi.sourceforge.net/>.
 --
@@ -21,7 +21,7 @@
 --
 
 -- Identify the script.
-function ident (self)
+function ident(self)
     package.path = self.script_dir .. '/?.lua'
     local C      = require 'quvi/const'
     local r      = {}
@@ -40,23 +40,25 @@ function query_formats(self)
 end
 
 -- Parse media URL.
-function parse (self)
+function parse(self)
     self.host_id = "break"
-    local page   = quvi.fetch(self.page_url)
 
-    local _,_,s = page:find('id="vid_title" content="(.-)"')
-    self.title  = s or error ("no match: media title")
+    local p = quvi.fetch(self.page_url)
 
-    local _,_,s = page:find("ContentID='(.-)'")
-    self.id     = s or error ("no match: media id")
+    self.title = p:match('id="vid_title" content="(.-)"')
+                  or error("no match: media title")
 
-    local _,_,s = page:find("FileName='(.-)'")
-    local fname = s or error ("no match: content file name")
+    self.id = p:match("ContentID='(.-)'")
+                or error("no match: media ID")
 
-    local _,_,s = page:find('flashVars.icon = "(.-)"')
-    local fhash = s or error ("no match: file hash")
+    local fn = p:match("FileName='(.-)'")
+                or error("no match: file name")
+
+    local fh = p:match('flashVars.icon = "(.-)"')
+                or error("no match: file hash")
+
+    self.url = {string.format("%s.flv?%s", fn, fh)}
 
-    self.url = { string.format("%s.flv?%s", fname,fhash) }
     return self
 end
 
