@@ -1,6 +1,6 @@
 
--- libquvi-scripts v0.4.3
--- Copyright (C) 2010  Toni Gundogdu <legatvs@gmail.com>
+-- libquvi-scripts v0.4.4
+-- Copyright (C) 2010-2012  Toni Gundogdu <legatvs@gmail.com>
 --
 -- This file is part of libquvi-scripts <http://quvi.sourceforge.net/>.
 --
@@ -21,7 +21,7 @@
 --
 
 -- Identify the script.
-function ident (self)
+function ident(self)
     package.path = self.script_dir .. '/?.lua'
     local C      = require 'quvi/const'
     local r      = {}
@@ -41,18 +41,20 @@ function query_formats(self)
 end
 
 -- Parse media URL.
-function parse (self)
+function parse(self)
     self.host_id = "google"
-    local page   = quvi.fetch(self.page_url)
 
-    local _,_,s = page:find("<title>(.-)</title>")
-    self.title  = s or error ("no match: media title")
+    local p = quvi.fetch(self.page_url)
 
-    local _,_,s = page:find("docid:'(.-)'")
-    self.id     = s or error ("no match: media id")
+    self.title = p:match("<title>(.-)</title>")
+                  or error("no match: media title")
+
+    self.id = p:match("docid:'(.-)'")
+                or error("no match: media ID")
+
+    local s = p:match("videoUrl%Wx3d(.-)%Wx26")
+                or error("no match: media URL")
 
-    local _,_,s = page:find("videoUrl%Wx3d(.-)%Wx26")
-    s           = s or error ("no match: url")
     local U     = require 'quvi/util'
     self.url    = {U.unescape(s)}
 
