@@ -1,6 +1,6 @@
 
--- libquvi-scripts v0.4.0
--- Copyright (C) 2010-2011  Toni Gundogdu <legatvs@gmail.com>
+-- libquvi-scripts v0.4.4
+-- Copyright (C) 2010-2012  Toni Gundogdu <legatvs@gmail.com>
 --
 -- This file is part of libquvi-scripts <http://quvi.sourceforge.net/>.
 --
@@ -20,8 +20,10 @@
 -- 02110-1301  USA
 --
 
+local LiveLeak = {} -- Utility functions specific to this script
+
 -- Identify the script.
-function ident (self)
+function ident(self)
     package.path = self.script_dir .. '/?.lua'
     local C      = require 'quvi/const'
     local r      = {}
@@ -29,6 +31,7 @@ function ident (self)
     r.formats    = "default"
     r.categories = C.proto_http
     local U      = require 'quvi/util'
+    LiveLeak.normalize(self)
     r.handles    = U.handles(self.page_url,
                     {r.domain}, {"view"}, {"i=[%w_]+"})
     return r
@@ -41,27 +44,48 @@ function query_formats(self)
 end
 
 -- Parse media URL.
-function parse (self)
+function parse(self)
     self.host_id = "liveleak"
-    local page   = quvi.fetch(self.page_url)
 
-    local _,_,s = page:find("<title>LiveLeak.com%s+%-%s+(.-)</")
-    self.title  = s or error ("no match: media title")
+    LiveLeak.normalize(self)
+    local p = quvi.fetch(self.page_url)
 
-    local _,_,s = self.page_url:find('view%?i=([%w_]+)')
-    self.id     = s or error ("no match: media id")
+    self.title = p:match("<title>LiveLeak.com%s+%-%s+(.-)</")
+                  or error("no match: media title")
 
-    local _,_,s      = page:find('config: "(.-)"')
-    local config_url = s or error ("no match: config")
+    self.id = self.page_url:match('view%?i=([%w_]+)')
+                or error("no match: media ID")
 
-    local opts       = { fetch_type = 'config' }
-    local U          = require 'quvi/util'
-    local config     = quvi.fetch (U.unescape(config_url), opts)
+    local c_url = p:match('config: "(.-)"')
+                    or error("no match: config")
 
-    local _,_,s = config:find("<file>(.-)</")
-    self.url    = {s or error ("no match: file")}
+    local U = require 'quvi/util'
+    local c = quvi.fetch(U.unescape(c_url), {fetch_type='config'})
+
+    self.url = {c:match("<file>(.-)</")
+                or error("no match: media URL")}
 
     return self
 end
 
+--
+-- Utility functions
+--
+
+function LiveLeak.normalize(self)
+    if not self.page_url then return self.page_url end
+
+    local U = require 'quvi/url'
+    local t = U.parse(self.page_url)
+
+    if not t.path then return self.page_url end
+
+    local i = t.path:match('/e/([_%w]+)')
+    if i then
+        t.query = 'i=' .. i
+        t.path = '/view'
+        self.page_url = U.build(t)
+    end
+end
+
 -- vim: set ts=4 sw=4 tw=72 expandtab:
