@@ -1,6 +1,6 @@
 
--- libquvi-scripts v0.4.3
--- Copyright (C) 2010  quvi project
+-- libquvi-scripts v0.4.4
+-- Copyright (C) 2010-2012  quvi project
 --
 -- This file is part of libquvi-scripts <http://quvi.sourceforge.net/>.
 --
@@ -21,7 +21,7 @@
 --
 
 -- Identify the script.
-function ident (self)
+function ident(self)
     package.path = self.script_dir .. '/?.lua'
     local C      = require 'quvi/const'
     local r      = {}
@@ -41,18 +41,19 @@ function query_formats(self)
 end
 
 -- Parse media URL.
-function parse (self)
+function parse(self)
     self.host_id = "youjizz"
-    local page   = quvi.fetch(self.page_url)
 
-    local _,_,s = page:find("<title>(.-)</")
-    self.title  = s or error ("no match: media title")
+    local p = quvi.fetch(self.page_url)
 
-    local _,_,s = page:find("%?id=(%d+)")
-    self.id     = s or error ("no match: media id")
+    self.title = p:match("<title>(.-)</")
+                  or error ("no match: media title")
 
-    local _,_,s = page:find('addVariable%("file",encodeURIComponent%("(.-)"')
-    self.url    = {s or error ("no match: file")}
+    self.id = p:match("%?id=(%d+)")
+                or error ("no match: media ID")
+
+    self.url = {p:match('addVariable%("file",encodeURIComponent%("(.-)"')
+                  or error ("no match: media URL")}
 
     return self
 end
